#!/usr/bin/env python
# -*- coding: UTF-8 -*-
import sys, os, string
from time import gmtime, strftime

poHeader="""# Tuxpaint-stamps [Language] translation.
# Copyright (C) 2002-"""+\
strftime("%Y", gmtime())+"\n"\
"""# This file is distributed under the same license as the Tuxpaint-stamps package.
# [Translator's name] <translator@email.address>, """+\
strftime("%Y", gmtime())+"\n"\
"""#
msgid ""
msgstr ""
"Project-Id-Version: tuxpaint-stamps\\n"
"Report-Msgid-Bugs-To: tuxpaint-i18n@lists.sourceforge.net\\n"
"MIME-Version: 1.0\\n"
"POT-Creation-Date: """+\
strftime("%Y-%m-%d %H:%M:%S+0000", gmtime())+"\\n\"\n"\
""""PO-Revision-Date: \\n"
"Content-Type: text/plain; charset=UTF-8\\n"
"Content-Transfer-Encoding: 8bit\\n"
"""
localeList = []

def lister(poLocale, dirname, filesindir):
    for fname in filesindir:
        fnlist = os.path.splitext(fname)
        if fnlist[1] == ".txt":
            if os.path.exists(dirname + "/" + fnlist[0] + '.svg') : #Check for SVG
                imgfile = fnlist[0] + '.svg'
            else :
                imgfile = fnlist[0] + '.png' # Else, assuming PNG
            txtFile = open(os.path.join(dirname, fname), 'rb')
            # write stamp filename down follow mark('#').
            poFile.write('\n#: ' + dirname + '/' + fnlist[0] + '\n')
            # provide an URL for viewing the stamp online
            poFile.write('#. View at http://www.tuxpaint.org/stamps/' + dirname[3:] + '/' + imgfile + '\n')
            # write description in msgid.
	    line = txtFile.readline()
	    if line[-1:] == "\n" :
		line = line[:-1]
	    line = string.replace(line, '"', '\\"')
            poFile.write('msgid "' + line + '"\n')
	    localeString = ""
            for line in txtFile.readlines():
                # replace " to \"
                line = string.replace(line, '"', '\\"')
                splitup = string.find(line,'.utf8')
                if splitup != -1 and line[0] != '#' :
                    locale = line[:splitup]
                    if locale not in localeList:
                        localeList.append(locale)
                    if locale == poLocale:
                        localeString = line[string.find(line, "=") + 1:-1]
            txtFile.close()
            # write translation or empty string in msgstr.
            poFile.write('msgstr "' + localeString + '"\n')

if __name__ == '__main__':
    poFile = open('./tuxpaint-stamps.pot', 'wb')
    print ">>", poFile.name
    poFile.write(poHeader)
    os.path.walk('../stamps/', lister, None)
    poFile.close()
#    for locale in localeList:
#        poFile = open('./tuxpaint-stamps-' + locale + '.po', 'wb')
#        poFile.write(poHeader)
#        os.path.walk('../stamps/', lister, locale)
#        poFile.close()



#!/usr/bin/env python
# -*- coding: UTF-8 -*-
import sys, os, glob, string

def lister(dummy, dirname, filesindir):
   for fname in filesindir:
       fnlist = os.path.splitext(fname)
       # change the file ext name to .txt whan ready.
       if fnlist[1] == ".txt":
           print ">> " + fname
           # open txt file to read.
           txtFile = open(os.path.join(dirname, fname), 'rb')
           # get first line : the stamp description.
           searchText_unescaped = txtFile.readline()[:-1]
           searchText = string.replace(searchText_unescaped, '"', '\\"')
           fullsearchText = "msgid \"" + searchText + "\"\n"
	   print "  " + searchText_unescaped
           if searchText in msgidsList:
               # reopen txt file to write.
               txtFile = open(os.path.join(dirname, fname), 'wb')
               # write back the description.
               txtFile.write(searchText_unescaped + '\n')
               # get locale code from the sorted localeList.
               for locale in localeList:
                   # seek position to the PO file's beginning.
                   localeFiles[locale].seek(0)
                   # search the searchText.
                   noFuzzy = 1
                   line = localeFiles[locale].readline()
                   while fullsearchText != line:
                       # determine fuzzy.
                       if line[:8] == '#, fuzzy':
                           noFuzzy = 0
                       else:
                           if line[:6] == 'msgstr':
                               noFuzzy = 1
                       line = localeFiles[locale].readline()
                   # if matched, read the next line, will be translated description.
                   line = localeFiles[locale].readline()
                   if line[:6] == 'msgstr' and line[8:-2] != "" and noFuzzy:
		       translation_unescaped = string.replace(line[8:-2], '\\"', '"')
                       txtFile.write("%s.utf8=%s\n" % (locale, translation_unescaped))
           txtFile.close()

def parsePOT(potFileName):
   try:
       potFile = open(potFileName, 'rb')
   except IOError, e:
       print "Unable to open the file:" , potFileName, e
   print potFileName
   # pass the pot header
   while len(potFile.readline()) > 1 : pass
   # parse filename and msgid
   for line in potFile.readlines():
       if line[:5] == 'msgid':
           # get msgid.
           msgidsList.append(line[7:-2])
           # if msgid has more one line,
           # we need change the way.
   potFile.close()

if __name__ == '__main__':
   localeFiles = {}
   localeList = []
   filesList = []
   msgidsList = []

   # parse pot file to fill msgidsList.
   parsePOT('./tuxpaint-stamps.pot')

   poFileNames = glob.glob('*.po')
   for poFileName in poFileNames:
       # add locale to localeList.
       localeList.append(poFileName[16:-3])
       # add po file to localeFiles.
       localeFiles[poFileName[16:-3]] = open(poFileName, 'rb')

   # sort locale code.
   localeList.sort()

   # walk around all .txt files.
   os.path.walk('../stamps/', lister, None)

   # close all po files.
   for locale in localeList:
       localeFiles[locale].close()
